Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(708)

Unified Diff: components/sync/engine_impl/sync_scheduler.h

Issue 2258873003: [Sync] Move sessions/ to engine/cycle/ and rename things to match. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Address comments. Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « components/sync/engine_impl/sync_cycle_event.h ('k') | components/sync/engine_impl/sync_scheduler_impl.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: components/sync/engine_impl/sync_scheduler.h
diff --git a/components/sync/engine_impl/sync_scheduler.h b/components/sync/engine_impl/sync_scheduler.h
index 97d9211ab3f56b414f9a74405bff83442e175e4d..cb4e36b705aece8c99a1844b13bcfe625ed31660 100644
--- a/components/sync/engine_impl/sync_scheduler.h
+++ b/components/sync/engine_impl/sync_scheduler.h
@@ -13,8 +13,8 @@
#include "base/compiler_specific.h"
#include "base/time/time.h"
#include "components/sync/base/invalidation_interface.h"
+#include "components/sync/engine_impl/cycle/sync_cycle.h"
#include "components/sync/engine_impl/nudge_source.h"
-#include "components/sync/sessions_impl/sync_session.h"
namespace tracked_objects {
class Location;
@@ -56,7 +56,7 @@ struct ClearParams {
base::Closure report_success_task;
};
-class SyncScheduler : public sessions::SyncSession::Delegate {
+class SyncScheduler : public SyncCycle::Delegate {
public:
enum Mode {
// In this mode, the thread only performs configuration tasks. This is
@@ -143,7 +143,7 @@ class SyncScheduler : public sessions::SyncSession::Delegate {
// can be requested through this function.
virtual void ScheduleInitialSyncNudge(syncer::ModelType model_type) = 0;
// Change status of notifications in the SyncSessionContext.
virtual void SetNotificationsEnabled(bool notifications_enabled) = 0;
// Called when credentials are updated by the user.
« no previous file with comments | « components/sync/engine_impl/sync_cycle_event.h ('k') | components/sync/engine_impl/sync_scheduler_impl.h » ('j') | no next file with comments »
@@ -143,7 +143,7 @@ class SyncScheduler : public sessions::SyncSession::Delegate {
// can be requested through this function.
virtual void ScheduleInitialSyncNudge(syncer::ModelType model_type) = 0;
- // Change status of notifications in the SyncSessionContext.
+ // Change status of notifications in the SyncCycleContext.
virtual void SetNotificationsEnabled(bool notifications_enabled) = 0;
// Called when credentials are updated by the user.

Powered by Google App Engine
This is Rietveld 408576698